<?php

class WpSaio
{
    private static $_instance = null;
    private static $saio_messaging_apps;

    public function __construct()
    {

    }
    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }
    public static function defaultApps()
    {
        return array(
            'facebook-messenger' => array(
                'icon' => WP_SAIO_URL . '/assets/home/img/facebook-messenger.png',
                'title' => __('Messenger', WP_SAIO_LANG_PREFIX),
                'shortcode' => 'wpsaio_facebook_messenger',
                'params' => array(
                    'url' => array(
                        'type' => 'text',
                        'required' => true,
                        'placeholder' => __('URL', WP_SAIO_LANG_PREFIX),
                        'desc' => __('Example: http://facebook.com/ninjateam.org/', WP_SAIO_LANG_PREFIX),
                    ),
                ),
            ),
            'whatsapp' => array(
                'icon' => WP_SAIO_URL . '/assets/home/img/whatsapp-logo.png',
                'title' => __('WhatsApp', WP_SAIO_LANG_PREFIX),
                'shortcode' => 'wpsaio_whatsapp',
                'params' => array(
                    'phone' => array(
                        'type' => 'text',
                        'required' => true,
                        'placeholder' => __('Phone Number', WP_SAIO_LANG_PREFIX),
                        'desc' => __('Example: +1 (800) 123-4567', WP_SAIO_LANG_PREFIX),
                    ),
                ),
            ),
            'snapchat' => array(
                'icon' => WP_SAIO_URL . '/assets/home/img/snapchat-logo.png',
                'title' => __('Snapchat', WP_SAIO_LANG_PREFIX),
                'shortcode' => 'wpsaio_snapchat',
                'params' => array(
                    'username' => array(
                        'type' => 'text',
                        'required' => true,
                        'placeholder' => __('Username', WP_SAIO_LANG_PREFIX),
                        'desc' => __('Example: ninjateam', WP_SAIO_LANG_PREFIX),
                    ),
                ),
            ),
            'line' => array(
                'icon' => WP_SAIO_URL . '/assets/home/img/line-icon.png',
                'title' => __('Line', WP_SAIO_LANG_PREFIX),
                'shortcode' => 'wpsaio_line',
                'params' => array(
                    'url' => array(
                        'type' => 'text',
                        'required' => true,
                        'placeholder' => __('QR Code URL', WP_SAIO_LANG_PREFIX),
                        'desc' => __('Example: http://line.me/ti/p/xxx', WP_SAIO_LANG_PREFIX),
                    ),
                ),
            ),
            'viber' => array(
                'icon' => WP_SAIO_URL . '/assets/home/img/viber-icon.png',
                'title' => __('Viber', WP_SAIO_LANG_PREFIX),
                'shortcode' => 'wpsaio_viber',
                'params' => array(
                    'account' => array(
                        'type' => 'text',
                        'required' => true,
                        'placeholder' => __('Public Account', WP_SAIO_LANG_PREFIX),
                        'desc' => __('Example: NinjaTeam', WP_SAIO_LANG_PREFIX),
                    ),
                ),
            ),
            'phone' => array(
                'icon' => WP_SAIO_URL . '/assets/home/img/phone-icon.png',
                'title' => __('Phone', WP_SAIO_LANG_PREFIX),
                'shortcode' => 'wpsaio_phone',
                'params' => array(
                    'phone_number' => array(
                        'type' => 'text',
                        'required' => true,
                        'placeholder' => __('Phone Number', WP_SAIO_LANG_PREFIX),
                        'desc' => __('Example: +1-800-123-4567', WP_SAIO_LANG_PREFIX),
                    ),
                ),
            ),
            'email' => array(
                'icon' => WP_SAIO_URL . '/assets/home/img/mail-icon.png',
                'title' => __('Email', WP_SAIO_LANG_PREFIX),
                'shortcode' => 'wpsaio_mail',
                'params' => array(
                    'email' => array(
                        'type' => 'text',
                        'required' => true,
                        'placeholder' => __('Email', WP_SAIO_LANG_PREFIX),
                        'desc' => __('Example: support@ninjateam.org', WP_SAIO_LANG_PREFIX),
                    ),
                ),
            ),
        );
    }
    public static function renderForm($apps = null)
    {
        if (is_null($apps)) {
            $apps = self::getMessagingApps();
        }

        $html = array();
        foreach ($apps as $k => $app) {
            $data = array(
                'icon' => $app['icon'],
                'title' => $app['title'],
                'inputs' => '',
                'type' => $k,
            );
            foreach ($app['params'] as $k2 => $input) {
                $data['inputs'] .= self::renderInput($k, $k2, $input);
            }
            $data['inputs'] .= self::renderDeleteBtn();
            $html[$k] = WpSaioView::load('admin.app.add-input', $data);
        }
        return $html;
    }
    public static function renderShortcodes()
    {
        $from_db = get_option('njt_wp_saio', null);
        if (is_null($from_db)) {
            return array();
        }

        $shortcodes = array();
        $apps = self::getMessagingApps();

        foreach ($apps as $k => $v) {
            if (in_array($k, array_keys($from_db))) {
                $atts = array();
                foreach ($from_db[$k]['params'] as $k2 => $v2) {
                    $atts[] = $k2 . '="' . esc_attr($v2) . '"';
                }
                $atts = implode(' ', $atts);
                $shortcodes[$k] = "[{$v['shortcode']} {$atts}]";
            }
        }
        return $shortcodes;
    }
    public static function renderInput($app, $key, $input)
    {
        $html = '';
        switch ($input['type']) {
            case 'text':
                $html = '<div class="input-group">
                <input class="regular-text" type="text" name="data['.$app.']['.$key.']" value="'.((isset($input['value'])) ? esc_attr($input['value']) : '').'" placeholder="'.esc_attr($input['placeholder']).'" '.(($input['required']) ? 'required="required"' : '').' />
                <p>'.$input['desc'].'</p>
                </div>
                ';
                break;
        }
        return $html;
    }
    public static function renderDeleteBtn()
    {
        return WpSaioView::load('admin.app.remove-input-btn');
    }
    public static function getMessagingApps()
    {
        self::$saio_messaging_apps = self::defaultApps();
        return apply_filters('wp-saio-messaging-apps', self::$saio_messaging_apps);
    }
    public static function generatePanel()
    {
        if (!is_admin()) {
            return false;
        }
        $apps = self::getMessagingApps();
        $added_apps = array_keys(get_option('njt_wp_saio', array()));
        ?>
        <form action="" method="POST" class="wp_saio_panel_form" id="">
            <div class="wp_saio_panel_wrap">
                <?php
                foreach ($apps as $k => $v) {
                    $icon = $v['icon'];
                    ?>
                    <div class="wp-saio-app <?php echo esc_attr($k); ?> <?php echo ((in_array($k, $added_apps)) ? ' added' : ''); ?>" data-type="<?php echo esc_attr($k) ?>">
                        <a href="javascript:void(0);">
                            <img src="<?php echo $icon; ?>" alt="" />
                        </a>
                    </div>
                    <?php
                }
                ?>
            </div>
            <div class="wp_saio_fields_wrap">
                <?php self::getExistData(); ?>
            </div>
            <button type="submit" name="save-wp-saio" class="wp-saio-submit-btn button button-primary">
                <?php _e('Save Changes', WP_SAIO_LANG_PREFIX); ?>                
            </button>
        </form>
        <?php
    }
    public static function getExistData()
    {
        $from_db = get_option('njt_wp_saio', null);
        if (is_null($from_db)) {
            return '';
        }
        $keys_from_db = array_keys($from_db);
        $apps = self::getMessagingApps();

        /*
         * Unset the apps not used and set value to the apps used.
         */
        $new_apps = array();
        foreach ($from_db as $k => $app) {
            if (isset($apps[$k]['params'])) {
                foreach ($apps[$k]['params'] as $k2 => $input) {
                    $new_apps[$k] = $apps[$k];
                    $new_apps[$k]['params'][$k2]['value'] = $app['params'][$k2];
                }
            }
        }

        $html = self::renderForm($new_apps);
        echo implode('', $html);
    }
    public static function generateFrontendButtons()
    {
        $from_db = get_option('njt_wp_saio', array());
        $from_db = array_reverse($from_db);
        if (is_null($from_db)) {
            return '';
        }
        $apps = self::getMessagingApps();
        $html = '';
        foreach ($from_db as $k => $v) {
            $data = array(
                'app' => $k,
                'title' => apply_filters('wpsaio-'.$k.'-home-title', $apps[$k]['title']),
            );
            $html .= WpSaioView::load('home.button', $data);
        }
        return $html;
    }
}
