<?php

class WpSaioInit
{
    private static $_instance = null;
    private $main_menu_slug = 'wp-support-all-in-one.php';
   
    public function __construct()
    {

        /*
         * Load Text Domain
         */
        add_action('plugins_loaded', array($this, 'loadTextDomain'));

        /*
         * Register Enqueue
         */
        add_action('admin_enqueue_scripts', array($this, 'registerAdminEnqueue'));
        add_action('wp_enqueue_scripts', array($this, 'registerEnqueue'));

        /*
         * Register Menu
         */
        add_action('admin_menu', array($this, 'registerAdminMenu'));

        /*
         * Admin head
         */
        add_action('admin_head', array($this, 'adminHead'));

        /*
         * WP Footer
         */
        add_action('wp_footer', array($this, 'wpFooter'));

        /*
         * Register Shortcode
         */
        WpSaioShortcodes::instance();

        add_action('admin_init', array($this, 'registerSettings'));
    }
    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }
    public function registerAdminEnqueue($hook_suffix)
    {
        wp_register_style('wp-saio', WP_SAIO_URL . '/assets/admin/css/wp-saio.css');
        wp_enqueue_style('wp-saio');

        wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_style('wp-color-picker');

        wp_register_script('wp-saio', WP_SAIO_URL . '/assets/admin/js/wp-saio.js', array('jquery', 'jquery-ui-sortable', 'wp-color-picker'));
        wp_enqueue_script('wp-saio');

        wp_localize_script('wp-saio', 'wp_saio_object',
            array(
                'are_you_sure' => __('Are you sure remove it?', WP_SAIO_LANG_PREFIX),
                'wp_saio_html_inputs' => json_encode(WpSaio::renderForm()),
                'add_media_text_title' => __('Choose Image', WP_SAIO_LANG_PREFIX),
                'add_media_text_button' => __('Choose Image', WP_SAIO_LANG_PREFIX),
            )
        );
    }
    public function registerEnqueue()
    {
        if (!$this->isActivePlugin()) {
            return false;
        }
        wp_register_style('wp-saio', WP_SAIO_URL . '/assets/home/css/wp-saio.css');
        wp_enqueue_style('wp-saio');

       
        wp_register_script('wp-saio', WP_SAIO_URL . '/assets/home/js/wp-saio.min.js', array('jquery'));
        wp_enqueue_script('wp-saio');
    }
    public function loadTextDomain()
    {
        load_plugin_textdomain('wp_saio', false, plugin_basename(WP_SAIO_DIR) . '/languages/');
    }
    public function registerAdminMenu()
    {
        $page_title = __('WP Support All In One', WP_SAIO_LANG_PREFIX);
        $menu_title = __('Support All In One', WP_SAIO_LANG_PREFIX);

        $main_menu = add_menu_page($page_title, $menu_title, 'manage_options', $this->main_menu_slug, array($this, 'wpSaioMenuCallBack'), WP_SAIO_URL . '/assets/admin/img/support-icon.svg');
        add_action('load-' . $main_menu, array($this, 'wpsaioLoadMainMenu'));
        
        $page_title = __('WP Support All In One Settings', WP_SAIO_LANG_PREFIX);
        $menu_title = __('Settings', WP_SAIO_LANG_PREFIX);

        add_submenu_page($this->main_menu_slug, $page_title, $menu_title, 'manage_options', 'wp-support-all-in-one-settings.php', array($this, 'wpSaioMenuSettingsCallBack'));
    }
    public function wpsaioLoadMainMenu()
    {
        global $plugin_page;
        $data = array();
        if (isset($_POST['save-wp-saio']) && isset($_POST['data'])) {
            $_data = $_POST['data'];
            foreach ($_data as $k => $v) {
                $data[$k]['params'] = array();
                foreach ($v as $k2 => $v2) {
                    $data[$k]['params'][$k2] = wp_unslash(trim($v2));
                }
            }
            update_option('njt_wp_saio', $data);

            wp_safe_redirect(esc_url(
                add_query_arg(array('page' => $this->main_menu_slug), admin_url('admin.php'))
            ));
        }
    }
    public function adminHead()
    {
        
    }
    public function wpFooter()
    {
        if (!$this->isActivePlugin()) {
            return;
        }
        $icon_bg_color = get_option('wpsaio_button_color', '');
        $btn_icon = get_option('wpsaio_button_icon', '');
        $data = array(
            'buttons' => WpSaio::generateFrontendButtons(),
            'contents' => do_shortcode(implode('', WpSaio::renderShortcodes())),
            'icon_bg_color' => $icon_bg_color,
            'btn_icon' => $btn_icon,
        );
        echo WpSaioView::load('home.main', $data);
    }
    private function isActivePlugin()
    {
        return (get_option('wpsaio_enable_plugin') == 1);
    }
    public function wpSaioMenuCallBack()
    {
        ?>
        <div class="wrap wp-saio-wrap">
            <h3 class="main-title"><?php _e('Choose messaging apps', WP_SAIO_LANG_PREFIX); ?></h3>
            <?php WpSaio::generatePanel(); ?>
        </div>
        <?php
    }
    public function wpSaioMenuSettingsCallBack()
    {
        wp_enqueue_media();
        echo WpSaioView::load('admin.settings');
    }
    public function registerSettings()
    {
        register_setting('wpsaio', 'wpsaio_enable_plugin');
        register_setting('wpsaio', 'wpsaio_bottom_distance');
        register_setting('wpsaio', 'wpsaio_button_icon');
        register_setting('wpsaio', 'wpsaio_button_color');
    }
}
